parallel
========

.. automodule:: jscatter.parallel
    :noindex:

=============

.. autosummary::
    doForList
    doForQlist
    psphereAverage
    randomPointsN
    rphitheta2xyz
    fibonacciLatticePointsOnSphere

---------------

.. automodule:: jscatter.parallel
    :members:
    :undoc-members:
    :show-inheritance:

   
   
   